@@ -207,8 +207,7 @@ time_t ModMArch::get( time_t bTm, time_t eTm, vector<TMess::SRec> &mess, const s
 	tC = (tC/60)*60;
 	cfg.cfg("MIN").setI(tC/60, true);
 	int eC = 0;
-	vector< vector<string> > full;
-	for( ; SYS->db().at().dataSeek(addr()+"."+archTbl(),"",eC++,cfg,false,&full) && SYS->sysTm() < upTo; ) {
+	for( ; SYS->db().at().dataSeek(addr()+"."+archTbl(),"",eC++,cfg,false,true) && SYS->sysTm() < upTo; ) {
 	    TMess::SRec rc(cfg.cfg("TM").getI(), cfg.cfg("TMU").getI(), cfg.cfg("CATEG").getS(),
 			    (TMess::Type)cfg.cfg("LEV").getI(), cfg.cfg("MESS").getS());
 	    if(rc.time >= bTm && rc.time <= eTm && abs(rc.level) >= level && re.test(rc.categ)) {
@@ -267,7 +266,7 @@ void ModMArch::cntrCmdProc( XMLNode *opt )
     if(opt->name() == "info") {
 	TMArchivator::cntrCmdProc(opt);
 	ctrRemoveNode(opt,"/prm/cfg/A_PRMS");
-	ctrMkNode("fld",opt,-1,"/prm/st/tarch",_("Archiving time, milliseconds"),R_R_R_,"root",SARH_ID,1,"tp","real");
+	ctrMkNode("fld",opt,-1,"/prm/st/tarch",_("Archiving time"),R_R_R_,"root",SARH_ID,1,"tp","str");
 	ctrMkNode("fld",opt,-1,"/prm/cfg/ADDR",EVAL_STR,startStat()?R_R_R_:RWRWR_,"root",SARH_ID,3,
 	    "dest","select","select","/db/list","help",TMess::labDB());
 	if(ctrMkNode("area",opt,-1,"/prm/add",_("Additional options"),R_R_R_,"root",SARH_ID)) {
