@@ -33,7 +33,7 @@
 #define MOD_NAME	_("DB SQLite")
 #define MOD_TYPE	SDB_ID
 #define VER_TYPE	SDB_VER
-#define MOD_VER		"2.8.0"
+#define MOD_VER		"3.0.3"
 #define AUTHORS		_("Roman Savochenko")
 #define DESCRIPTION	_("BD module. Provides support of the BD SQLite.")
 #define LICENSE		"GPL2"
@@ -195,7 +195,7 @@ void MBD::sqlReq( const string &req, vector< vector<string> > *tbl, char intoTra
     int repCnt = 0;
 rep:
     //Put the request
-    if(mess_lev() == TMess::Debug) mess_debug((nodePath()+"tracing/").c_str(), _("Request: \"%s\""), req.c_str());
+    if(mess_lev() == TMess::Debug) mess_debug((owner().nodePath()+id()+"_tracing/").c_str(), _("Request: \"%s\""), req.c_str());
     rc = sqlite3_get_table(m_db, Mess->codeConvOut(cd_pg.c_str(),req).c_str(), &result, &nrow, &ncol, &zErrMsg);
     if(rc != SQLITE_OK) {
 	string err = _("Unknown error");
@@ -235,21 +235,24 @@ void MBD::transOpen( )
     if(reqCnt > 1000) transCommit();
 
     MtxAlloc res(connRes, true);
-    bool begin = !reqCnt;
-    if(begin) trOpenTm = TSYS::curTime();
+    int reqCnt_ = reqCnt;
+    if(!reqCnt_) trOpenTm = TSYS::curTime();
     reqCnt++;
     reqCntTm = TSYS::curTime();
 
-    if(begin) sqlReq("BEGIN;");
+    if(!reqCnt_) sqlReq("BEGIN;");
 }
 
 void MBD::transCommit( )
 {
     MtxAlloc res(connRes, true);
-    bool commit = reqCnt;
-    reqCnt = reqCntTm = 0;
+    int reqCnt_ = reqCnt;
+    reqCnt = 0;
+    reqCntTm = 0;
 
-    if(commit) sqlReq("COMMIT;");
+    if(reqCnt_)
+	try { sqlReq("COMMIT;"); }
+	catch(TError&) { }	//!!!! Pass spare commit errors of the sort "cannot commit - no transaction is active(1)"
 }
 
 void MBD::transCloseCheck( )
@@ -329,11 +332,8 @@ void MTable::fieldStruct( TConfig &cfg )
     }
 }
 
-bool MTable::fieldSeek( int row, TConfig &cfg, vector< vector<string> > *full )
+bool MTable::fieldSeek( int row, TConfig &cfg, const string &cacheKey )
 {
-    vector< vector<string> >	inTbl,
-				&tbl = full ? *full : inTbl;
-
     if(tblStrct.empty()) throw err_sys(_("Table is empty."));
     mLstUse = SYS->sysTm();
 
@@ -379,28 +379,35 @@ bool MTable::fieldSeek( int row, TConfig &cfg, vector< vector<string> > *full )
 	}
     }
 
+    vector< vector<string> >	inTbl, *tbl = &inTbl;
+    MtxAlloc res(owner().connRes);
+    if(cacheKey.size()) { res.lock(); tbl = &seekSess[cacheKey]; }
+
     //Request
-    if(!full || !full->size() || (row%SEEK_PRELOAD_LIM) == 0) {
+    if(!cacheKey.size() || !tbl->size() || (row%SEEK_PRELOAD_LIM) == 0) {
 	if(first_sel) return false;
 	req += " FROM '" + TSYS::strEncode(name(),TSYS::SQL,"'") + "' " + ((next)?req_where:"");
-	if(!full) req += " LIMIT " +  i2s(row) + ",1";
+	if(!cacheKey.size()) req += " LIMIT " +  i2s(row) + ",1";
 	else req += " LIMIT " + i2s((row/SEEK_PRELOAD_LIM)*SEEK_PRELOAD_LIM) + "," + i2s(SEEK_PRELOAD_LIM);
 	req += ";";
 
-	tbl.clear();
-	owner().sqlReq(req, &tbl/*, false*/);	// For seek to deletion into save context do not set to "false"
+	tbl->clear();
+	owner().sqlReq(req, tbl/*, false*/);	// For seek to deletion into save context do not set to "false"
     }
 
-    row = full ? (row%SEEK_PRELOAD_LIM)+1 : 1;
-    if(tbl.size() < 2 || (full && row >= (int)tbl.size())) return false;
+    row = cacheKey.size() ? (row%SEEK_PRELOAD_LIM)+1 : 1;
+    if(tbl->size() < 2 || (cacheKey.size() && row >= (int)tbl->size())) {
+	if(cacheKey.size()) seekSess.erase(cacheKey);
+	return false;
+    }
 
     //Processing of the query
-    for(unsigned iFld = 0; iFld < tbl[0].size(); iFld++) {
-	sid = tbl[0][iFld];
+    for(unsigned iFld = 0; iFld < (*tbl)[0].size(); iFld++) {
+	sid = (*tbl)[0][iFld];
 	TCfg *u_cfg = cfg.at(sid, true);
-	if(u_cfg) setVal(*u_cfg, tbl[row][iFld]);
-	else if(trPresent && sid.compare(0,3,Mess->lang2Code()+"#") == 0 && tbl[row][iFld].size() && (u_cfg=cfg.at(sid.substr(3),true)))
-	    setVal(*u_cfg, tbl[row][iFld], true);
+	if(u_cfg) setVal(*u_cfg, (*tbl)[row][iFld]);
+	else if(trPresent && sid.compare(0,3,Mess->lang2Code()+"#") == 0 && (*tbl)[row][iFld].size() && (u_cfg=cfg.at(sid.substr(3),true)))
+	    setVal(*u_cfg, (*tbl)[row][iFld], true);
     }
 
     return true;
@@ -421,7 +428,7 @@ void MTable::fieldGet( TConfig &cfg )
     bool first_sel = true, next_wr = false, trPresent = false;
     for(unsigned iFld = 1; iFld < tblStrct.size(); iFld++) {
 	sid = tblStrct[iFld][1];
-	TCfg *u_cfg = cfg.at(sid,true);
+	TCfg *u_cfg = cfg.at(sid, true);
 	if(!u_cfg && !Mess->translDyn() && sid.compare(0,3,Mess->lang2Code()+"#") == 0) {
 	    u_cfg = cfg.at(sid.substr(3), true);
 	    if(u_cfg && !(u_cfg->fld().flg()&TFld::TransltText)) continue;
@@ -467,16 +474,15 @@ void MTable::fieldSet( TConfig &cfg )
     mLstUse = SYS->sysTm();
 
     string sid, sval;
-    bool isVarTextTransl = (!Mess->lang2CodeBase().empty() && Mess->lang2Code() != Mess->lang2CodeBase());
 
     //Get config fields list
     vector<string> cf_el;
     cfg.cfgList(cf_el);
 
     //Check for translation present
-    bool trPresent = isVarTextTransl, trDblDef = false;
+    bool trPresent = Mess->translCfg(), trDblDef = false;
     for(unsigned iFld = 1; iFld < tblStrct.size(); iFld++) {
-	if(trPresent && (!isVarTextTransl || trDblDef)) break;
+	if(trPresent && (!Mess->translCfg() || trDblDef)) break;
 	sid = tblStrct[iFld][1];
 	if(sid.size() > 3) {
 	    if(!trPresent && !Mess->translDyn() && sid.compare(0,3,Mess->lang2Code()+"#") == 0) trPresent = true;
@@ -595,7 +601,7 @@ void MTable::fieldFix( TConfig &cfg, bool trPresent )
 {
     bool toUpdate = false,
 	 appMode = cfg.reqKeys() || (cfg.incomplTblStruct() && !tblStrct.empty()),	//Only for append no present fields
-	 isVarTextTransl = trPresent || (!Mess->lang2CodeBase().empty() && Mess->lang2Code() != Mess->lang2CodeBase());
+	 isVarTextTransl = trPresent || Mess->translCfg();
 
     //Get config fields list
     vector<string> cf_el;
@@ -629,10 +635,10 @@ void MTable::fieldFix( TConfig &cfg, bool trPresent )
 	    if(cf_el[iCf] == tblStrct[iFld][1]) {
 		if(appMode) break;
 		switch(cf.fld().type()) {
-		    case TFld::String:	if(tblStrct[iFld][2] != "TEXT")	toUpdate = true;	break;
+		    case TFld::String:	{ if(tblStrct[iFld][2] != "TEXT") toUpdate = true;	break; }
 		    case TFld::Integer: case TFld::Boolean:
-					if(tblStrct[iFld][2] != "INTEGER")toUpdate = true;	break;
-		    case TFld::Real:	if(tblStrct[iFld][2] != "DOUBLE")toUpdate = true;	break;
+					{ if(tblStrct[iFld][2] != "INTEGER") toUpdate = true;	break; }
+		    case TFld::Real:	{ if(tblStrct[iFld][2] != "DOUBLE") toUpdate = true;	break; }
 		    default: toUpdate = true;
 		}
 		all_flds += (all_flds.size()?",\"":"\"") + TSYS::strEncode(tblStrct[iFld][1],TSYS::SQL,"\"") + "\"";
@@ -707,7 +713,7 @@ void MTable::fieldFix( TConfig &cfg, bool trPresent )
     crtReq += ", PRIMARY KEY (" + pr_keys + "));";
     owner().sqlReq(crtReq, NULL, true);
 
-    //Restore data from temporary table
+    //Restore data from the temporary table
     if(all_flds.size()) {
 	req = "INSERT INTO '" + TSYS::strEncode(name(),TSYS::SQL,"'") + "'(" + all_flds + ") SELECT " + all_flds +
 	      " FROM 'temp_" + TSYS::strEncode(name(),TSYS::SQL,"'") + "';DROP TABLE 'temp_" + TSYS::strEncode(name(),TSYS::SQL,"'") + "';";
