@@ -130,8 +130,7 @@ void Block::loadIO( const string &blk_db, const string &blk_id, bool force )
     while(ioSize() > (int)mLnk.size()) { mLnk.push_back(SLnk()); mLnk.back().tp = FREE; }
 
     //IO values loading and links set, by seek
-    vector<vector<string> > full;
-    for(int fldCnt = 0; SYS->db().at().dataSeek(bd,mod->nodePath()+bd_tbl,fldCnt++,cfg,false,&full); ) {
+    for(int fldCnt = 0; SYS->db().at().dataSeek(bd,mod->nodePath()+bd_tbl,fldCnt++,cfg,false,true); ) {
 	int io = func()->ioId(cfg.cfg("ID").getS());
 	if(io < 0) continue;
 	setS(io, cfg.cfg("VAL").getS());
