@@ -169,6 +169,11 @@ void TMdContr::disable_( )
     reqRes.resRelease();
 }
 
+void TMdContr::load_( )
+{
+    if(SYS->cfgCtx() && toEnable() && !enableStat())	enable();
+}
+
 void TMdContr::start_( )
 {
     if(prcSt) return;
@@ -1195,7 +1200,7 @@ void TMdPrm::disable( )
 
 void TMdPrm::load_( )
 {
-    //TParamContr::load_();
+    if(SYS->cfgCtx() && toEnable() && !enableStat())	enable();
     loadIO();
 }
 
