@@ -95,13 +95,12 @@ void TProt::load_( )
 	//gCfg.cfgViewAll(false);
 	vector<string> itLs;
 	map<string, bool> itReg;
-	vector<vector<string> > full;
 
 	//  Search into DB
 	SYS->db().at().dbList(itLs, true);
 	itLs.push_back(DB_CFG);
 	for(unsigned iDB = 0; iDB < itLs.size(); iDB++)
-	    for(int fldCnt = 0; SYS->db().at().dataSeek(itLs[iDB]+"."+modId()+"_node",nodePath()+modId()+"_node",fldCnt++,gCfg,false,&full); ) {
+	    for(int fldCnt = 0; SYS->db().at().dataSeek(itLs[iDB]+"."+modId()+"_node",nodePath()+modId()+"_node",fldCnt++,gCfg,false,true); ) {
 		string id = gCfg.cfg("ID").getS();
 		if(!nPresent(id)) nAdd(id, (itLs[iDB]==SYS->workDB())?"*.*":itLs[iDB]);
 		nAt(id).at().load(&gCfg);
@@ -262,10 +261,10 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
 	if(!tro.startStat()) tro.start();
 	if(prt == "TCP") {		// Modbus/TCP protocol process
 	    //Encode MBAP (Modbus Application Protocol)
-	    int tid = rand();
+	    uint16_t tid = rand()%65536;
 	    mbap.reserve(pdu.size()+7);
-	    mbap.append((char*)&tid,2);		//Transaction ID
-	    mbap.append(2,(char)0);		//Protocol ID
+	    mbap.append((char*)&tid, 2);	//Transaction ID
+	    mbap.append(2, (char)0);		//Protocol ID
 	    mbap += (char)((pdu.size()+1)>>8);	//PDU size MSB
 	    mbap += (char)(pdu.size()+1);	//PDU size LSB
 	    mbap += (char)node;			//Unit identifier
@@ -275,6 +274,8 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
 	    int resp_len = tro.messIO(mbap.data(), mbap.size(), buf, sizeof(buf), reqTm);
 	    rez.assign(buf,resp_len);
 	    if(rez.size() < 7)	err = _("13:Error of the server response");
+	    else if(TSYS::getUnalign16(rez.data()) != tid)
+		err = TSYS::strMess(_("13:The response Transaction ID %d is not suitable to the request one %d."), TSYS::getUnalign16(rez.data()), (int)tid);
 	    else {
 		unsigned resp_sz = (unsigned short)(rez[4]<<8) | (unsigned char)rez[5];
 
@@ -293,7 +294,7 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
 	    mbap.reserve(pdu.size()+3);
 	    mbap += (uint8_t)node;		//Unit identifier
 	    mbap += pdu;
-	    uint16_t crc = CRC16( mbap );
+	    uint16_t crc = CRC16(mbap);
 	    mbap += (crc>>8);
 	    mbap += crc;
 
@@ -754,12 +755,11 @@ void Node::loadIO( )
 	TFunction *f = data && data->func() ? data->func() : this;
 
 	//Load IO
-	vector<vector<string> > full;
 	vector<string> u_pos;
 	TConfig cfg(&owner().nodeIOEl());
 	cfg.cfg("NODE_ID").setS(id(), TCfg::ForceUse);
 	cfg.cfg("VALUE").setExtVal(true);
-	for(int ioCnt = 0; SYS->db().at().dataSeek(fullDB()+"_io",owner().nodePath()+tbl()+"_io",ioCnt++,cfg,false,&full); ) {
+	for(int ioCnt = 0; SYS->db().at().dataSeek(fullDB()+"_io",owner().nodePath()+tbl()+"_io",ioCnt++,cfg,false,true); ) {
 	    string sid = cfg.cfg("ID").getS();
 	    int iid = f->ioId(sid);
 
@@ -837,13 +837,12 @@ void Node::saveIO( )
 	}
 
 	//Clear IO
-	vector<vector<string> > full;
 	cfg.cfgViewAll(false);
-	for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB()+"_io",owner().nodePath()+tbl()+"_io",fldCnt++,cfg,false,&full); ) {
+	for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB()+"_io",owner().nodePath()+tbl()+"_io",fldCnt++,cfg); ) {
 	    string sio = cfg.cfg("ID").getS();
 	    if(f->ioId(sio) < 0) {
 		if(!SYS->db().at().dataDel(fullDB()+"_io",owner().nodePath()+tbl()+"_io",cfg,true,false,true)) break;
-		if(full.empty()) fldCnt--;
+		fldCnt--;
 	    }
 	}
     }
