@@ -1,7 +1,7 @@
 
 //OpenSCADA module DAQ.OPC_UA file: mod_daq.cpp
 /***************************************************************************
- *   Copyright (C) 2009-2017 by Roman Savochenko, <rom_as@oscada.org>      *
+ *   Copyright (C) 2009-2020 by Roman Savochenko, <roman@oscada.org>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -62,8 +62,8 @@ void TTpContr::postEnable( int flag )
     fldAdd(new TFld("TM_REST",_("Restore timeout, seconds"),TFld::Integer,TFld::NoFlag,"4","10","1;3600"));
     fldAdd(new TFld("SYNCPER",_("Sync inter remote station period, seconds"),TFld::Integer,TFld::NoFlag,"4","60","0;1000"));
     fldAdd(new TFld("EndPoint",_("End point"),TFld::String,TFld::NoFlag,"50","opc.tcp://localhost"));
-    fldAdd(new TFld("SecPolicy",_("Security policy"),TFld::String,TFld::Selected,"20","None","None;Basic128Rsa15;Basic256",_("None;Basic128Rsa15;Basic256")));
-    fldAdd(new TFld("SecMessMode",_("Message security mode"),TFld::Integer,TFld::Selected,"1","1",
+    fldAdd(new TFld("SecPolicy",_("Security policy"),TFld::String,TFld::Selectable,"20","None","None;Basic128Rsa15;Basic256",_("None;Basic128Rsa15;Basic256")));
+    fldAdd(new TFld("SecMessMode",_("Message security mode"),TFld::Integer,TFld::Selectable,"1","1",
 	TSYS::strMess("%d;%d;%d",MS_None,MS_Sign,MS_SignAndEncrypt).c_str(),_("None;Sign;Sign&Encrypt")));
     fldAdd(new TFld("Cert",_("Certificate (PEM)"),TFld::String,TFld::FullText,"10000"));
     fldAdd(new TFld("PvKey",_("Private key (PEM)"),TFld::String,TFld::FullText,"10000"));
@@ -85,7 +85,7 @@ TMdContr::TMdContr( string name_c, const string &daq_db, TElem *cfgelem ) : TCon
     mSched(cfg("SCHEDULE")), mPrior(cfg("PRIOR")), mRestTm(cfg("TM_REST")), mSync(cfg("SYNCPER")),
     mEndP(cfg("EndPoint")), mSecPol(cfg("SecPolicy")), mSecMessMode(cfg("SecMessMode")), mCert(cfg("Cert")), mPvKey(cfg("PvKey")),
     mAuthUser(cfg("AuthUser")), mAuthPass(cfg("AuthPass")), mPAttrLim(cfg("AttrsLimit").getId()),
-    prcSt(false), callSt(false), mPCfgCh(false), alSt(-1), mBrwsVar(TSYS::strMess(_("Root folder (%d)"),OpcUa_RootFolder)),
+    mPer(1e9), prcSt(false), callSt(false), mPCfgCh(false), alSt(-1), mBrwsVar(TSYS::strMess(_("Root folder (%d)"),OpcUa_RootFolder)),
     acqErr(dataRes()), tmDelay(0), servSt(0)
 {
     cfg("PRM_BD").setS("OPC_UA_Prm_"+name_c);
@@ -134,6 +134,8 @@ string TMdContr::authData( )
 
 void TMdContr::reqService( XML_N &io )
 {
+    if(tr.freeStat())	return;
+
     ResAlloc res(nodeRes(), true);
     io.setAttr("err", "");
 
@@ -170,6 +172,7 @@ void TMdContr::enable_( )
 	SYS->transport().at().at(TSYS::strParse(trName,0,".")).at().outAdd(TSYS::strParse(trName,1,".").substr(4));
 	tr = SYS->transport().at().nodeAt(trName, 0, '.');
 	tr.at().setDscr(TSYS::strMess(_("OPC UA automatic created transport for '%s' controller."),id().c_str()));
+	tr.at().modifClr();
     }
     enSt = true;
     setEndPoint(endPoint());
@@ -185,9 +188,6 @@ void TMdContr::start_( )
     //Establish connection
     //try { tr.at().start(); } catch(TError &err) { mess_err(err.cat.c_str(), "%s", err.mess.c_str()); }
 
-    //Schedule process
-    mPer = TSYS::strSepParse(cron(),1,' ').empty() ? vmax(0,(int64_t)(1e9*s2r(cron()))) : 0;
-
     servSt = 0;
     tmDelay = 0;
 
@@ -200,7 +200,7 @@ void TMdContr::stop_( )
     //Stop the request and calc data task
     SYS->taskDestroy(nodePath('.',true));
 
-    alarmSet(TSYS::strMess(_("DAQ.%s.%s: connect to data source: %s."),owner().modId().c_str(),id().c_str(),_("STOP")), TMess::Info);
+    alarmSet(TSYS::strMess(_("Connection to the data source: %s."),_("STOP")), TMess::Info);
     alSt = -1;
 }
 
@@ -225,12 +225,12 @@ void TMdContr::prmEn( const string &id, bool val )
 {
     MtxAlloc res(enRes, true);
 
-    unsigned i_prm;
-    for(i_prm = 0; i_prm < pHd.size(); i_prm++)
-	if(pHd[i_prm].at().id() == id) break;
+    unsigned iPrm;
+    for(iPrm = 0; iPrm < pHd.size(); iPrm++)
+	if(pHd[iPrm].at().id() == id) break;
 
-    if(val && i_prm >= pHd.size()) pHd.push_back(at(id));
-    if(!val && i_prm < pHd.size()) pHd.erase(pHd.begin()+i_prm);
+    if(val && iPrm >= pHd.size()) pHd.push_back(at(id));
+    if(!val && iPrm < pHd.size()) pHd.erase(pHd.begin()+iPrm);
     if(startStat()) mPCfgCh = true;
 }
 
@@ -262,14 +262,14 @@ void *TMdContr::Task( void *icntr )
 		req.childClear();
 		req.childAdd("node")->setAttr("prmId", "OPC_UA_Server")->setAttr("prmAttr", "ServerStatus_State")->
 		    setAttr("nodeId", i2s(OpcUa_Server_ServerStatus_State))->setAttr("attributeId", i2s(AId_Value));
-		for(unsigned i_p = 0; i_p < cntr.pHd.size(); i_p++) {
-		    if(firstCall || cntr.tmDelay == 0) cntr.pHd[i_p].at().attrPrc();
-		    cntr.pHd[i_p].at().vlList(als);
-		    for(unsigned i_a = 0; i_a < als.size(); i_a++) {
-			nId = TSYS::strLine(cntr.pHd[i_p].at().vlAt(als[i_a]).at().fld().reserve(), 0);
+		for(unsigned iP = 0; iP < cntr.pHd.size(); iP++) {
+		    if(firstCall || cntr.tmDelay == 0) cntr.pHd[iP].at().attrPrc();
+		    cntr.pHd[iP].at().vlList(als);
+		    for(unsigned iA = 0; iA < als.size(); iA++) {
+			nId = TSYS::strLine(cntr.pHd[iP].at().vlAt(als[iA]).at().fld().reserve(), 0);
 			if(nId.empty())	continue;
-			req.childAdd("node")->setAttr("prmId", cntr.pHd[i_p].at().id())->
-			    setAttr("prmAttr", als[i_a])->setAttr("nodeId", nId)->setAttr("attributeId", i2s(AId_Value));
+			req.childAdd("node")->setAttr("prmId", cntr.pHd[iP].at().id())->
+			    setAttr("prmAttr", als[iA])->setAttr("nodeId", nId)->setAttr("attributeId", i2s(AId_Value));
 		    }
 		}
 		cntr.mPCfgCh = false;
@@ -283,15 +283,15 @@ void *TMdContr::Task( void *icntr )
 	    int ndSt = 0;
 	    AutoHD<TVal> vl;
 	    res.lock();
-	    for(unsigned i_c = 0, i_p = 0, varTp = 0; i_c < req.childSize() && i_p < cntr.pHd.size(); i_c++) {
+	    for(unsigned i_c = 0, iP = 0, varTp = 0; i_c < req.childSize() && iP < cntr.pHd.size(); i_c++) {
 		XML_N *cnX = req.childGet(i_c);
 		if(cnX->attr("prmId") == "OPC_UA_Server" && cnX->attr("prmAttr") == "ServerStatus_State")
 		{ cntr.servSt = strtoul(cnX->text().c_str(),NULL,10); continue; }
-		while(cnX->attr("prmId") != cntr.pHd[i_p].at().id()) i_p++;
-		if(i_p >= cntr.pHd.size()) break;
-		if(cntr.pHd[i_p].at().vlPresent(cnX->attr("prmAttr"))) {
+		while(cnX->attr("prmId") != cntr.pHd[iP].at().id()) iP++;
+		if(iP >= cntr.pHd.size()) break;
+		if(cntr.pHd[iP].at().vlPresent(cnX->attr("prmAttr"))) {
 		    ndSt = strtol(cnX->attr("Status").c_str(),NULL,0);
-		    vl = cntr.pHd[i_p].at().vlAt(cnX->attr("prmAttr"));
+		    vl = cntr.pHd[iP].at().vlAt(cnX->attr("prmAttr"));
 		    if((varTp=s2i(cnX->attr("VarTp")))&OpcUa_Array && !isErr && !ndSt) {
 			TArrayObj *curArr = new TArrayObj();
 			string vEl;
@@ -325,8 +325,7 @@ void *TMdContr::Task( void *icntr )
 		//mess_err(cntr.nodePath().c_str(), "%s", cntr.acqErr.getVal().c_str());
 		if(cntr.alSt <= 0) {
 		    cntr.alSt = 1;
-		    cntr.alarmSet(TSYS::strMess(_("DAQ.%s.%s: connect to data source: %s."),cntr.owner().modId().c_str(),cntr.id().c_str(),
-								TRegExp(":","g").replace(cntr.acqErr.getVal(),"=").c_str()));
+		    cntr.alarmSet(TSYS::strMess(_("Connection to the data source: %s."),TRegExp(":","g").replace(cntr.acqErr.getVal(),"=").c_str()));
 		}
 		cntr.tmDelay = cntr.restTm();
 		continue;
@@ -335,8 +334,7 @@ void *TMdContr::Task( void *icntr )
 		cntr.acqErr.setVal("");
 		if(cntr.alSt != 0) {
 		    cntr.alSt = 0;
-		    cntr.alarmSet(TSYS::strMess(_("DAQ.%s.%s: connect to data source: %s."),cntr.owner().modId().c_str(),cntr.id().c_str(),_("OK")),
-				    TMess::Info);
+		    cntr.alarmSet(TSYS::strMess(_("Connection to the data source: %s."),_("OK")), TMess::Info);
 		}
 	    }
 	    res.unlock();
@@ -358,8 +356,10 @@ bool TMdContr::cfgChange( TCfg &co, const TVariant &pc )
     TController::cfgChange(co, pc);
 
     try {
-	if(co.name() == "EndPoint" && enableStat()) {
-	    tr.at().setAddr("TCP:"+epParse());
+	if(co.fld().name() == "SCHEDULE")
+	    mPer = TSYS::strSepParse(cron(),1,' ').empty() ? vmax(0,(int64_t)(1e9*s2r(cron()))) : 0;
+	else if(co.name() == "EndPoint" && enableStat()) {
+	    tr.at().setAddr("TCP:"+epParse()); tr.at().modifClr();
 	    ResAlloc res(nodeRes(), false);
 	    SecuritySetting ss("", -1);
 	    if(epLst.find(co.getS()) != epLst.end()) ss = epLst[co.getS()];
@@ -463,8 +463,8 @@ void TMdContr::cntrCmdProc( XMLNode *opt )
 	if(stP != string::npos && stC != string::npos) cNodeId = TSYS::strDecode(mBrwsVar.substr(stP+1,stC-stP-1));
 
 	XML_N req("opc.tcp"); req.setAttr("id", "Read")->setAttr("timestampsToReturn", i2s(TS_NEITHER));
-	for(int i_a = 1; i_a <= 22; i_a++)
-	    req.childAdd("node")->setAttr("nodeId", cNodeId)->setAttr("attributeId", i2s(i_a));
+	for(int iA = 1; iA <= 22; iA++)
+	    req.childAdd("node")->setAttr("nodeId", cNodeId)->setAttr("attributeId", i2s(iA));
 	reqService(req);
 	if(!req.attr("err").empty()) {
 	    //mess_err(nodePath().c_str(), "%s", req.attr("err").c_str());
@@ -472,11 +472,11 @@ void TMdContr::cntrCmdProc( XMLNode *opt )
 	}
 
 	// Get result
-	for(unsigned i_a = 0; i_a < req.childSize(); i_a++) {
-	    if(strtol(req.childGet(i_a)->attr("Status").c_str(),NULL,0)) continue;
+	for(unsigned iA = 0; iA < req.childSize(); iA++) {
+	    if(strtol(req.childGet(iA)->attr("Status").c_str(),NULL,0)) continue;
 	    string nANm = _("Unknown");
-	    string nAVl = req.childGet(i_a)->text();
-	    switch(i_a+1) {
+	    string nAVl = req.childGet(iA)->text();
+	    switch(iA+1) {
 		case AId_NodeId: nANm = _("NodeId");	break;
 		case AId_NodeClass:
 		    nANm = _("NodeClass");
@@ -633,7 +633,7 @@ void TMdPrm::disable( )
 
 string TMdPrm::attrPrc( )
 {
-    MtxAlloc res(dataRes());
+    MtxAlloc res(enRes);
 
     bool srchOK = false;
     XML_N req("opc.tcp");
@@ -674,10 +674,10 @@ string TMdPrm::attrPrc( )
 
 	    res.lock();
 	    // Find for already presented attribute
-	    for(unsigned i_a = 0; i_a < pEl.fldSize() && !srchOK; i_a++)
-		if(TSYS::strLine(pEl.fldAt(i_a).reserve(),0) == snd) {
-		    if(pEl.fldAt(i_a).type() != vtp)
-			try { pEl.fldDel(i_a); break; }
+	    for(unsigned iA = 0; iA < pEl.fldSize() && !srchOK; iA++)
+		if(TSYS::strLine(pEl.fldAt(iA).reserve(),0) == snd) {
+		    if(pEl.fldAt(iA).type() != vtp)
+			try { pEl.fldDel(iA); break; }
 			catch(TError &err) { }
 		    srchOK = true;
 		}
@@ -685,11 +685,8 @@ string TMdPrm::attrPrc( )
 	    // Create new attribute
 	    if(!srchOK) {
 		//  Prepare attribute id
-		string aid = TSYS::strEncode(req.childGet(1)->text(), TSYS::oscdID);
-		if(vlPresent(aid))
-		    for(int i_v = 1; true; i_v++)
-			if(!vlPresent(aid+i2s(i_v)))
-			{ aid += i2s(i_v); break; }
+		string aid = TSYS::strEncode((isdigit(req.childGet(1)->text()[0])?TSYS::strParse(req.childGet(1)->text(),1,":"):req.childGet(1)->text()), TSYS::oscdID);
+		while(vlPresent(aid))	aid = TSYS::strLabEnum(aid);
 
 		//  Value type prepare
 		TFld::Type vtp = TFld::String;
@@ -704,7 +701,7 @@ string TMdPrm::attrPrc( )
 		// Browse name
 		string aNm = req.childGet(2)->text();
 		size_t nmPos = aNm.find(":");
-		if(nmPos!=string::npos) aNm.erase(0,nmPos+1);
+		if(nmPos!=string::npos) aNm.erase(0, nmPos+1);
 
 		//  Flags prepare
 		unsigned vflg = TVal::DirWrite;
@@ -724,12 +721,12 @@ string TMdPrm::attrPrc( )
 
     //Find for delete attribute
     res.lock();
-    for(unsigned i_a = 0, i_p; i_a < pEl.fldSize(); ) {
-	for(i_p = 0; i_p < als.size(); i_p++)
-	    if(TSYS::strLine(pEl.fldAt(i_a).reserve(),0) == als[i_p])	break;
-	if(i_p >= als.size())
-	    try{ pEl.fldDel(i_a); continue; } catch(TError &err) { }
-	i_a++;
+    for(unsigned iA = 0, iP; iA < pEl.fldSize(); ) {
+	for(iP = 0; iP < als.size(); iP++)
+	    if(TSYS::strLine(pEl.fldAt(iA).reserve(),0) == als[iP])	break;
+	if(iP >= als.size())
+	    try{ pEl.fldDel(iA); continue; } catch(TError &err) { }
+	iA++;
     }
 
     return "";
@@ -846,7 +843,7 @@ void TMdPrm::vlGet( TVal &val )
 	//Check remote attributes for error status
 	uint32_t firstErr = 0;
 	vector<uint32_t> astls;
-	MtxAlloc res(dataRes(), true);
+	MtxAlloc res(enRes, true);
 	for(unsigned iA = 0; iA < pEl.fldSize(); iA++) {
 	    astls.push_back(pEl.fldAt(iA).len());
 	    if(pEl.fldAt(iA).len() && !firstErr) firstErr = pEl.fldAt(iA).len();
@@ -863,15 +860,9 @@ void TMdPrm::vlSet( TVal &vo, const TVariant &vl, const TVariant &pvl )
     if(!enableStat() || !owner().startStat())	{ vo.setS(EVAL_STR, 0, true); return; }
 
     //Send to active reserve station
-    if(owner().redntUse()) {
-	if(vl == pvl) return;
-	XMLNode req("set");
-	req.setAttr("path",nodePath(0,true)+"/%2fserv%2fattr")->childAdd("el")->setAttr("id",vo.name())->setText(vl.getS());
-	SYS->daq().at().rdStRequest(owner().workId(),req);
-	return;
-    }
+    if(vlSetRednt(vo,vl,pvl))	return;
 
-    if(vl.isEVal() || vl == pvl) return;
+    if(vl.isEVal() || vl == pvl)return;
 
     //Direct write
     XML_N req("opc.tcp");
