@@ -41,7 +41,7 @@
 #define MOD_NAME	_("Siemens DAQ and Beckhoff")
 #define MOD_TYPE	SDAQ_ID
 #define VER_TYPE	SDAQ_VER
-#define MOD_VER		"3.3.0"
+#define MOD_VER		"3.3.2"
 #define AUTHORS		_("Roman Savochenko")
 #define DESCRIPTION	_("Provides for support of data sources of Siemens PLCs by means of Hilscher CIF cards (using the MPI protocol)\
  and LibnoDave library (or the own implementation) for the rest. Also there is supported the data sources of the firm Beckhoff for the\
@@ -499,7 +499,7 @@ TParamContr *TMdContr::ParamAttach( const string &name, int type ) { return new
 
 void TMdContr::load_( )
 {
-    //TController::load_();
+    if(SYS->cfgCtx() && toEnable() && !enableStat())	enable();
 }
 
 void TMdContr::save_( )
@@ -1760,7 +1760,7 @@ void TMdPrm::disable( )
 
 void TMdPrm::load_( )
 {
-    //TParamContr::load_();
+    if(SYS->cfgCtx() && toEnable() && !enableStat())	enable();
     loadIO();
 }
 
