@@ -32,7 +32,7 @@
 #define MOD_NAME	_("Own protocol of OpenSCADA")
 #define MOD_TYPE	SPRT_ID
 #define VER_TYPE	SPRT_VER
-#define MOD_VER		"1.5.0"
+#define MOD_VER		"1.8.0"
 #define AUTHORS		_("Roman Savochenko")
 #define DESCRIPTION	_("Provides own OpenSCADA protocol based at XML and the control interface of OpenSCADA.")
 #define LICENSE		"GPL2"
@@ -170,6 +170,7 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
     char buf[1000];
     string req, resp, header;
     int rez, resp_len, off, head_end;
+    string reqNm = io.name();
 
     MtxAlloc res(tro.reqRes(), true);
 
@@ -177,7 +178,13 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
     bool authForce = s2i(io.attr("rqAuthForce")); io.attrDel("rqAuthForce");
     int conTm = s2i(io.attr("conTm"));	io.attrDel("conTm");
     string user = io.attr("rqUser");	io.attrDel("rqUser");
+    user = TSYS::strEncode(user, TSYS::Custom, " \r\n\t%");
     string pass = io.attr("rqPass");	io.attrDel("rqPass");
+    if(!pass.size())	pass = EMPTY_PASS;
+    pass = TSYS::strEncode(pass, TSYS::Custom, " \r\n\t%");
+    //int64_t seq = tro.conPrm("seq").getI();
+    //seq = (seq != EVAL_INT && seq < 1000) ? seq+1 : 0;
+    //tro.setConPrm("seq", seq); io.setAttr("rqSeq", i2s(seq));
     string data = io.save();
     io.clear();
 
@@ -185,8 +192,9 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
 	int reqTrs = tro.attempts(), iTr = 0;
 	string errTr;
 	for(iTr = 0; iTr < reqTrs; ) {
+	    int64_t authID = tro.conPrm("auth"+user);
 	    //Session open
-	    if(!isDir && (tro.prm1() < 0 || authForce)) {
+	    if(!isDir && (authID == EVAL_INT || authForce)) {
 		req = "SES_OPEN " + user + " " + pass + "\x0A";
 
 		if(mess_lev() == TMess::Debug) mess_debug(nodePath().c_str(), _("SES_OPEN request: %d"), req.size());
@@ -209,7 +217,7 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
 			if(rez == atoi(ERR_AUTH)) { io.setAttr("rez",i2s(rez))->setText(header.substr(off)); break; }
 			throw TError(nodePath().c_str(), _("Error the station '%s': %s."), tro.id().c_str(), header.substr(off).c_str());
 		    }
-		    tro.setPrm1(s2i(header.substr(off)));
+		    tro.setConPrm("auth"+user, (authID=s2i(header.substr(off))));
 		} else throw TError(nodePath().c_str(), _("Error the station '%s': error the response format."), tro.id().c_str());
 	    }
 
@@ -219,7 +227,7 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
 	    if(reqCompr) data = TSYS::strCompr(data, comprLev());
 
 	    if(isDir)	req = "REQDIR " + user + " " + pass + " " + i2s(data.size()*(reqCompr?-1:1)) + "\x0A" + data;
-	    else	req = "REQ " + i2s(tro.prm1()) + " " + i2s(data.size()*(reqCompr?-1:1)) + "\x0A" + data;
+	    else	req = "REQ " + i2s(authID) + " " + i2s(data.size()*(reqCompr?-1:1)) + "\x0A" + data;
 
 	    if(mess_lev() == TMess::Debug) mess_debug(nodePath().c_str(), _("REQ send: %d"), req.size());
 
@@ -234,7 +242,7 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
 
 	    if(mess_lev() == TMess::Debug) mess_debug(nodePath().c_str(), _("REQ first response %d"), resp.size());
 
-	    // Get head
+	    // Get the head
 	    head_end = header.size() + 1;
 	    off = 0;
 	    //header = TSYS::strLine(resp,0,&head_end);
@@ -242,15 +250,16 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
 		throw TError(nodePath().c_str(),_("Error the station '%s' response."),tro.id().c_str());
 	    rez = s2i(TSYS::strParse(header,0," ",&off));
 	    if(rez == atoi(ERR_AUTH)) {
-		tro.setPrm1(-1);
+		tro.setConPrm("auth"+user, (authID=EVAL_INT));
 		if(isDir) { io.setAttr("rez",i2s(rez))->setText(header.substr(off)); break; }
 		else continue;
 	    }
+
 	    if(rez > 0 || off >= (int)header.size())
 		throw TError(nodePath().c_str(),_("Error the station '%s': %s."), tro.id().c_str(), buf+off);
 	    int resp_size = s2i(header.substr(off));
 
-	    // Wait tail
+	    // Wait the tail
 	    while((int)resp.size() < abs(resp_size)+head_end) {
 		resp_len = tro.messIO(NULL, 0, buf, sizeof(buf));
 		if(!resp_len) { errTr = _("Not full respond."); iTr++; continue; }
@@ -262,6 +271,11 @@ void TProt::outMess( XMLNode &io, TTransportOut &tro )
 	    if(resp_size < 0) io.load(TSYS::strUncompr(resp.substr(head_end)), XMLNode::LD_NoTxtSpcRemEnBeg);
 	    else io.load(resp.substr(head_end), XMLNode::LD_NoTxtSpcRemEnBeg);
 
+	    if(reqNm != io.name())
+	    { errTr = TSYS::strMess(_("The response '%s' is not suitable to the request '%s'."),io.name().c_str(),reqNm.c_str()); iTr++; continue; }
+	    //if(s2i(io.attr("rqSeq")) != seq)
+	    //{ errTr = TSYS::strMess(_("The response sequence %d is not suitable to the request one %d."),s2i(io.attr("rqSeq")),(int)seq); iTr++; continue; }
+
 	    return;
 	}
 
@@ -343,6 +357,7 @@ bool TProtIn::mess( const string &request, string &answer )
     int ses_id = -1;
     int req_sz = 0;
     char user[256] = "", pass[256] = "";
+    string user_, pass_;
 
     reqBuf += request;
 
@@ -354,7 +369,10 @@ bool TProtIn::mess( const string &request, string &answer )
 
     if(req.compare(0,8,"SES_OPEN") == 0) {
 	sscanf(req.c_str(), "SES_OPEN %255s %255s", user, pass);
-	if((ses_id=mod->sesOpen(user,pass,TSYS::strLine(srcAddr(),0))) < 0)
+	user_ = TSYS::strDecode(user, TSYS::Custom);
+	pass_ = TSYS::strDecode(pass, TSYS::Custom);
+	if(pass_ == EMPTY_PASS) pass_ = "";
+	if((ses_id=mod->sesOpen(user_,pass_,TSYS::strLine(srcAddr(),0))) < 0)
 	    answer = "REZ " ERR_AUTH " Error authentication: wrong the user or password.\x0A";
 	else answer = "REZ " ERR_NO " " + i2s(ses_id) + "\x0A";
     }
@@ -373,8 +391,11 @@ bool TProtIn::mess( const string &request, string &answer )
 	TProt::SAuth auth;
 	if(sscanf(req.c_str(),"REQ %d %d",&ses_id,&req_sz) == 2) auth = mod->sesGet(ses_id);
 	else if(sscanf(req.c_str(),"REQDIR %255s %255s %d",user,pass,&req_sz) == 3) {
-	    if(SYS->security().at().usrPresent(user) && SYS->security().at().usrAt(user).at().auth(pass,&auth.pHash))
-	    { auth.tAuth = 1; auth.name = user; }
+	    user_ = TSYS::strDecode(user, TSYS::Custom);
+	    pass_ = TSYS::strDecode(pass, TSYS::Custom);
+	    if(pass_ == EMPTY_PASS) pass_ = "";
+	    if(SYS->security().at().usrPresent(user_) && SYS->security().at().usrAt(user_).at().auth(pass_,&auth.pHash))
+	    { auth.tAuth = 1; auth.name = user_; }
 	}
 	else { answer = "REZ " ERR_CMD " Command format error.\x0A"; reqBuf.clear(); return false; }
 
