@@ -1,7 +1,7 @@
 
 //OpenSCADA module Special.SystemTests file: test_DB.h
 /***************************************************************************
- *   Copyright (C) 2005-2018 by Roman Savochenko, <rom_as@oscada.org>      *
+ *   Copyright (C) 2005-2020 by Roman Savochenko, <roman@oscada.org>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -74,7 +74,7 @@ class TestDB : public TFunction
 		bd.at().at(n_bd).at().enable();
 
 		mod->mess(id(),_("Open the table '%s'."),n_tbl.c_str());
-		bd.at().at(n_bd).at().open(n_tbl,true);
+		bd.at().at(n_bd).at().open(n_tbl, true);
 		mod->mess(id(),_("Connect to the table '%s'."),n_tbl.c_str());
 		AutoHD<TTable> tbl = bd.at().at(n_bd).at().at(n_tbl);
 
@@ -91,14 +91,14 @@ class TestDB : public TFunction
 		//Test for create records
 		mod->mess(id(),_("Create records."));
 		int64_t ctime = TSYS::curTime();
-		for(int i_fld = 0; i_fld < experem; i_fld++) {
-		    bd_cfg.cfg("name").setS("Sh"+i2s(i_fld));
-		    bd_cfg.cfg("descr").setS("Shifr '"+i2s(i_fld)+"'");
-		    bd_cfg.cfg("val").setR(sqrt(i_fld));
-		    bd_cfg.cfg("id").setI(i_fld);
-		    bd_cfg.cfg("stat").setB((i_fld%2)==0?true:false);
-		    bd_cfg.cfg("reqKey").setS(i_fld<(experem/2)?"req0":"req1");
-		    bd_cfg.cfg("reqVal").setS(i_fld<(experem/2)?"Request 0 value":"Request 1 value");
+		for(int iFld = 0; iFld < experem; iFld++) {
+		    bd_cfg.cfg("name").setS("Sh"+i2s(iFld));
+		    bd_cfg.cfg("descr").setS("Shifr '"+i2s(iFld)+"'");
+		    bd_cfg.cfg("val").setR(sqrt(iFld));
+		    bd_cfg.cfg("id").setI(iFld);
+		    bd_cfg.cfg("stat").setB((iFld%2)==0?true:false);
+		    bd_cfg.cfg("reqKey").setS(iFld<(experem/2)?"req0":"req1");
+		    bd_cfg.cfg("reqVal").setS(iFld<(experem/2)?"Request 0 value":"Request 1 value");
 		    tbl.at().fieldSet(bd_cfg);
 		}
 		mod->mess(id(),_("Created %d records for time %f sec."),experem,1e-6*(TSYS::curTime()-ctime));
@@ -106,12 +106,12 @@ class TestDB : public TFunction
 		//Check for update fields
 		mod->mess(id(),_("Update records."));
 		ctime = TSYS::curTime();
-		for(int i_fld = 0; i_fld < experem; i_fld++) {
-		    bd_cfg.cfg("name").setS("Sh"+i2s(i_fld));
-		    bd_cfg.cfg("descr").setS("New shifr \""+i2s(i_fld)+"\"");
-		    bd_cfg.cfg("val").setR(2.*sqrt(i_fld));
-		    bd_cfg.cfg("id").setI(2*i_fld);
-		    bd_cfg.cfg("stat").setB((i_fld%2)==0?false:true);
+		for(int iFld = 0; iFld < experem; iFld++) {
+		    bd_cfg.cfg("name").setS("Sh"+i2s(iFld));
+		    bd_cfg.cfg("descr").setS("New shifr \""+i2s(iFld)+"\"");
+		    bd_cfg.cfg("val").setR(2.*sqrt(iFld));
+		    bd_cfg.cfg("id").setI(2*iFld);
+		    bd_cfg.cfg("stat").setB((iFld%2)==0?false:true);
 		    bd_cfg.cfg("reqKey").setView(false);
 		    bd_cfg.cfg("reqVal").setView(false);
 		    tbl.at().fieldSet(bd_cfg);
@@ -123,9 +123,9 @@ class TestDB : public TFunction
 		ctime = TSYS::curTime();
 		bd_cfg.cfgViewAll(false);
 		bd_cfg.cfg("reqKey").setReqKey(true);
-		bd_cfg.cfg("reqKey").setS("req0",TCfg::ForceUse|TCfg::ExtValTwo);
-		bd_cfg.cfg("reqKey").setS("reqNew0",TCfg::ForceUse);
-		bd_cfg.cfg("reqVal").setS("Request new 0 value",TCfg::ForceUse);
+		bd_cfg.cfg("reqKey").setS("req0", TCfg::ForceUse|TCfg::ExtValTwo);
+		bd_cfg.cfg("reqKey").setS("reqNew0", TCfg::ForceUse);
+		bd_cfg.cfg("reqVal").setS("Request new 0 value", TCfg::ForceUse);
 		tbl.at().fieldSet(bd_cfg);
 		mod->mess(id(),_("Updated %d records by a request key for time %f sec."),experem/2,1e-6*(TSYS::curTime()-ctime));
 		bd_cfg.cfg("reqKey").setReqKey(false);
@@ -135,33 +135,33 @@ class TestDB : public TFunction
 		//Check for get fields
 		mod->mess(id(),_("Check records."));
 		ctime = TSYS::curTime();
-		for(int i_fld = 0; i_fld < experem; i_fld++) {
-		    bd_cfg.cfg("name").setS("Sh"+i2s(i_fld));
+		for(int iFld = 0; iFld < experem; iFld++) {
+		    bd_cfg.cfg("name").setS("Sh"+i2s(iFld));
 		    tbl.at().fieldGet(bd_cfg);
 
-		    if(experem > 155 && i_fld == 155)
+		    if(experem > 155 && iFld == 155)
 			mod->mess(id(),_("Record #155='%s'; Descr='%s'; Value=%f; Id=%d; Stat=%d."),//; reqKey='%s'; reqVal='%s'."),
 			    bd_cfg.cfg("name").getS().c_str(), bd_cfg.cfg("descr").getS().c_str(),
 			    bd_cfg.cfg("val").getR(), bd_cfg.cfg("id").getI(), bd_cfg.cfg("stat").getB());/*,
 			    bd_cfg.cfg("reqKey").getS().c_str(), bd_cfg.cfg("reqVal").getS().c_str());*/	//By some GLibC crashes
 
-		    if(bd_cfg.cfg("name").getS() != (string("Sh")+i2s(i_fld)))
+		    if(bd_cfg.cfg("name").getS() != (string("Sh")+i2s(iFld)))
 			throw TError(nodePath().c_str(),_("Field <Sh> '%s' != '%s' error."),
-			    bd_cfg.cfg("name").getS().c_str(),(string("Sh")+i2s(i_fld)).c_str());
-		    if(bd_cfg.cfg("descr").getS() != (string("New shifr \"")+i2s(i_fld)+"\""))
+			    bd_cfg.cfg("name").getS().c_str(),(string("Sh")+i2s(iFld)).c_str());
+		    if(bd_cfg.cfg("descr").getS() != (string("New shifr \"")+i2s(iFld)+"\""))
 			throw TError(nodePath().c_str(),_("Field <descr> '%s' != '%s' error."),
-			    bd_cfg.cfg("descr").getS().c_str(),(string("New shifr ")+i2s(i_fld)).c_str());
-		    //ceil(100.*bd_cfg.cfg("val").getR()) != ceil(2.*sqrt(i_fld)) ||
-		    if(bd_cfg.cfg("id").getI() != (2*i_fld))
-			throw TError(nodePath().c_str(),_("Field <id> %d != %d error."),bd_cfg.cfg("id").getI(), (2*i_fld) );
-		    if(bd_cfg.cfg("stat").getB() != ((i_fld%2)==0?false:true))
-			throw TError(nodePath().c_str(),_("Field <stat> %d != %d error."),bd_cfg.cfg("stat").getB(),((i_fld%2)==0?false:true));
-		    if(bd_cfg.cfg("reqKey").getS() != ((i_fld<(experem/2))?"reqNew0":"req1"))
+			    bd_cfg.cfg("descr").getS().c_str(),(string("New shifr ")+i2s(iFld)).c_str());
+		    //ceil(100.*bd_cfg.cfg("val").getR()) != ceil(2.*sqrt(iFld)) ||
+		    if(bd_cfg.cfg("id").getI() != (2*iFld))
+			throw TError(nodePath().c_str(),_("Field <id> %d != %d error."),bd_cfg.cfg("id").getI(), (2*iFld) );
+		    if(bd_cfg.cfg("stat").getB() != ((iFld%2)==0?false:true))
+			throw TError(nodePath().c_str(),_("Field <stat> %d != %d error."),bd_cfg.cfg("stat").getB(),((iFld%2)==0?false:true));
+		    if(bd_cfg.cfg("reqKey").getS() != ((iFld<(experem/2))?"reqNew0":"req1"))
 			throw TError(nodePath().c_str(), _("Field <reqKey> '%s' != '%s' error."),
-			    bd_cfg.cfg("reqKey").getS().c_str(), ((i_fld<(experem/2))?"reqNew0":"req1"));
-		    if(bd_cfg.cfg("reqVal").getS() != ((i_fld<(experem/2))?"Request new 0 value":"Request 1 value"))
+			    bd_cfg.cfg("reqKey").getS().c_str(), ((iFld<(experem/2))?"reqNew0":"req1"));
+		    if(bd_cfg.cfg("reqVal").getS() != ((iFld<(experem/2))?"Request new 0 value":"Request 1 value"))
 			throw TError(nodePath().c_str(), _("Field <reqVal> '%s' != '%s' error."),
-			    bd_cfg.cfg("reqVal").getS().c_str(), ((i_fld<(experem/2))?"Request new 0 value":"Request 1 value"));
+			    bd_cfg.cfg("reqVal").getS().c_str(), ((iFld<(experem/2))?"Request new 0 value":"Request 1 value"));
 		}
 		mod->mess(id(),_("Got %d records for time %f sec."),experem,1e-6*(TSYS::curTime()-ctime));
 
@@ -176,9 +176,8 @@ class TestDB : public TFunction
 		//Seek in preload all records
 		mod->mess(id(), _("Seek records in preload."));
 		ctime = TSYS::curTime();
-		vector< vector<string> > full;
 		pos = 0;
-		while(tbl.at().fieldSeek(pos,bd_cfg,&full)) pos++;
+		while(tbl.at().fieldSeek(pos,bd_cfg,TSYS::addr2str(&bd_cfg))) pos++;
 		bd_cfg.cfg("name").setKeyUse(true);
 		mod->mess(id(), _("Sought %d records in preload for time %f sec."), pos, 1e-6*(TSYS::curTime()-ctime));
 
@@ -223,8 +222,8 @@ class TestDB : public TFunction
 
 		//Delete fields
 		ctime = TSYS::curTime();
-		for(int i_fld = 0; i_fld < experem; i_fld++) {
-		    bd_cfg.cfg("name").setS("Sh"+i2s(i_fld),true);
+		for(int iFld = 0; iFld < experem; iFld++) {
+		    bd_cfg.cfg("name").setS("Sh"+i2s(iFld),true);
 		    tbl.at().fieldDel(bd_cfg);
 		}
 		mod->mess(id(),_("Deleted %d records for time %f sec."),experem,1e-6*(TSYS::curTime()-ctime));
