@@ -85,6 +85,8 @@ protected:
     void showEvent( QShowEvent* );
     void closeEvent( QCloseEvent* );
 
+    void updatePrjList( const string &stage = "" );
+
 private:
     //Attributes
     QListWidget	*prjsLs;
@@ -100,6 +102,8 @@ private slots:
     void projCreateUpdt( );
     void projSelect( );
     void projSwitch( const QString &prj = "" );
+
+    void prjsLsCtxMenuRequested( const QPoint &pos );
 };
 
 //*************************************************
@@ -124,7 +128,11 @@ public:
     void updLookFeel( );
 
     bool notify( QObject *receiver, QEvent *event );
+#if QT_VERSION < 0x050000
     void saveState( QSessionManager &manager );
+#else
+    void saveStateRequest( QSessionManager &sessionManager );
+#endif
 
     int stExec( );
     void stClear( bool inDestr = false );
@@ -176,9 +184,7 @@ public:
     TUIMod( string name );
     ~TUIMod( );
 
-    // Module's info attributes
-    string modInfo( const string &name );
-    void   modInfo( vector<string> &list );
+    void perSYSCall( unsigned int cnt );
 
     bool endRun( )	{ return mEndRun; }
     bool startCom( )	{ return mStartCom; }
@@ -234,7 +240,10 @@ private:
     char	*qtArgV[10];			//Argument's values
     char	qtArgBuf[1000];			//Arguments' strings buffer
 
+    ResMtx	splashRes;
+    SplashFlag	splashTp;
     QSplashScreen *splash;
+    time_t	splashTm;
 };
 
 extern TUIMod *mod;
