@@ -177,10 +177,9 @@ void WidgetLib::load_( TConfig *icfg )
 
     //Create new widgets
     map<string, bool>	itReg;
-    vector<vector<string> > full;
     TConfig cEl(&mod->elWdg());
     //cEl.cfgViewAll(false);
-    for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB(),mod->nodePath()+tbl(),fldCnt++,cEl,false,&full); ) {
+    for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB(),mod->nodePath()+tbl(),fldCnt++,cEl,false,true); ) {
 	string fId = cEl.cfg("ID").getS();
 	if(!present(fId)) { add(fId, "", ""); at(fId).at().setEnableByNeed(); }
 	at(fId).at().load(&cEl);
@@ -250,8 +249,7 @@ void WidgetLib::mimeDataList( vector<string> &list, const string &idb ) const
     cEl.cfgViewAll(false);
 
     list.clear();
-    vector<vector<string> > full;
-    for(int fldCnt = 0; SYS->db().at().dataSeek(wdb+"."+wtbl,mod->nodePath()+wtbl,fldCnt,cEl,false,&full); fldCnt++)
+    for(int fldCnt = 0; SYS->db().at().dataSeek(wdb+"."+wtbl,mod->nodePath()+wtbl,fldCnt,cEl,false,true); fldCnt++)
 	list.push_back(cEl.cfg("ID").getS());
 }
 
@@ -565,25 +563,17 @@ string LWidget::calcLang( ) const
 {
     if(!proc().size() && !parent().freeStat()) return parent().at().calcLang();
 
-    string iprg = proc();
-    if(iprg.find("\n") == string::npos) {
-	iprg = iprg+"\n";
-	cfg("PROC").setS(iprg);
-    }
-    return iprg.substr(0,iprg.find("\n"));
+    return TSYS::strLine(proc(), 0);
 }
 
-bool LWidget::calcProgTr( )	{ return (!proc().size() && !parent().freeStat()) ? parent().at().calcProgTr() : cfg("PR_TR"); }
-
 string LWidget::calcProg( ) const
 {
     if(!proc().size() && !parent().freeStat()) return parent().at().calcProg();
 
     string iprg = proc();
-    size_t lng_end = iprg.find("\n");
-    if(lng_end == string::npos) lng_end = 0;
-    else lng_end++;
-    return iprg.substr(lng_end);
+    int off = 0;
+    TSYS::strLine(iprg, 0, &off);
+    return iprg.substr(off);
 }
 
 string LWidget::calcProgStors( const string &attr )
@@ -599,12 +589,6 @@ int LWidget::calcPer( ) const	{ return (mProcPer < 0 && !parent().freeStat()) ?
 
 void LWidget::setCalcLang( const string &ilng )	{ cfg("PROC").setS(ilng.empty() ? "" : ilng+"\n"+calcProg()); }
 
-void LWidget::setCalcProgTr( bool vl )
-{
-    if(!proc().size() && !parent().freeStat())	parent().at().setCalcProgTr(vl);
-    else cfg("PR_TR") = vl;
-}
-
 void LWidget::setCalcProg( const string &iprg )	{ cfg("PROC").setS(calcLang()+"\n"+iprg); }
 
 void LWidget::setParentNm( const string &isw )
@@ -697,12 +681,11 @@ void LWidget::loadIO( )
     //Load cotainer widgets
     if(!isContainer()) return;
     map<string, bool>   itReg;
-    vector<vector<string> > full;
     TConfig cEl(&mod->elInclWdg());
     string db  = ownerLib().DB();
     string tbl = ownerLib().tbl()+"_incl";
     cEl.cfg("IDW").setS(id(),true);
-    for(int fldCnt = 0; SYS->db().at().dataSeek(db+"."+tbl,mod->nodePath()+tbl,fldCnt++,cEl,false,&full); ) {
+    for(int fldCnt = 0; SYS->db().at().dataSeek(db+"."+tbl,mod->nodePath()+tbl,fldCnt++,cEl,false,true); ) {
 	string sid  = cEl.cfg("ID").getS();
 	if(cEl.cfg("PARENT").getS() == "<deleted>") {
 	    if(wdgPresent(sid))	wdgDel(sid);
@@ -792,9 +775,11 @@ void LWidget::wdgAdd( const string &wid, const string &name, const string &path,
     }
 
     //Call heritors include widgets update
+    ResAlloc res(mHeritRes);
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(mHerit[iH].at().enable())
 	    mHerit[iH].at().inheritIncl(wid);
+    res.unlock();
 
     if(toRestoreInher)
 	throw TError(TError::Core_CntrWarning, nodePath().c_str(), _("Restoring '%s' from the base container!"), wid.c_str());
@@ -831,6 +816,7 @@ void LWidget::procChange( bool src )
     if(!src && proc().size()) return;
 
     //Update heritors' procedures
+    ResAlloc res(mHeritRes);
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(mHerit[iH].at().enable())
 	    mHerit[iH].at().procChange(false);
@@ -846,7 +832,9 @@ void LWidget::inheritAttr( const string &attr )
 bool LWidget::cfgChange( TCfg &co, const TVariant &pc )
 {
     if(co.name() == "PR_TR") cfg("PROC").setNoTransl(!calcProgTr());
-    else if(co.name() == "PROC" && co.getS() != pc.getS()) procChange();
+
+    if(co.getS() == pc.getS()) return true;
+    if(co.name() == "PROC") procChange();
     modif();
     return true;
 }
@@ -873,6 +861,7 @@ void LWidget::cntrCmdProc( XMLNode *opt )
 TVariant LWidget::stlReq( Attr &a, const TVariant &vl, bool wr )
 {
     //To register the property on the project side
+    ResAlloc res(mHeritRes);
     for(unsigned iH = 0; !wr && iH < mHerit.size(); iH++)
 	if(mHerit[iH].at().enable())
 	    mHerit[iH].at().stlReq(a, vl, wr);
@@ -1066,6 +1055,7 @@ string CWidget::resourceGet( const string &id, string *mime )
 void CWidget::procChange( bool src )
 {
     //Update heritors' procedures
+    ResAlloc res(mHeritRes);
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(mHerit[iH].at().enable())
 	    mHerit[iH].at().procChange(false);
