@@ -186,14 +186,12 @@ void Project::load_( TConfig *icfg )
     if(icfg) *(TConfig*)this = *icfg;
     else SYS->db().at().dataGet(DB()+"."+mod->prjTable(), mod->nodePath()+"PRJ/", *this);
 
-    vector<vector<string> > full;
-
     //Create new pages
     map<string, bool> itReg;
     TConfig cEl(&mod->elPage());
     //cEl.cfgViewAll(false);
     cEl.cfg("OWNER").setS("/"+id(), true);
-    for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB(),mod->nodePath()+tbl()+"/",fldCnt++,cEl,false,&full); ) {
+    for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB(),mod->nodePath()+tbl()+"/",fldCnt++,cEl,false,true); ) {
 	string fId = cEl.cfg("ID").getS();
 	if(!present(fId)) add(fId, "", "");
 	at(fId).at().load(&cEl);
@@ -216,7 +214,7 @@ void Project::load_( TConfig *icfg )
     TConfig cStl(&mod->elPrjStl());
     string svl;
     vector<string> vlst;
-    for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB()+"_stl",nodePath()+tbl()+"_stl",fldCnt++,cStl,false,&full); ) {
+    for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB()+"_stl",nodePath()+tbl()+"_stl",fldCnt++,cStl,false,true); ) {
 	vlst.clear();
 	for(int iS = 0; iS < 10; iS++) {
 	    svl = cStl.cfg(TSYS::strMess("V_%d",iS)).getS();
@@ -244,10 +242,9 @@ void Project::save_( )
 	    mimeDataSet(pls[iM], mimeType, mimeData, DB());
 	}
 	// Session's data copy
-	vector<vector<string> > full;
 	string wtbl = tbl()+"_ses";
 	TConfig cEl(&mod->elPrjSes());
-	for(int fldCnt = 0; SYS->db().at().dataSeek(mOldDB+"."+wtbl,"",fldCnt,cEl,false,&full); fldCnt++)
+	for(int fldCnt = 0; SYS->db().at().dataSeek(mOldDB+"."+wtbl,"",fldCnt,cEl,false,true); fldCnt++)
 	    SYS->db().at().dataSet(DB()+"."+wtbl,"",cEl);
     }
 
@@ -264,13 +261,12 @@ void Project::save_( )
     }
 
     // Checking for the removed properties
-    vector<vector<string> > full;
     res.request(true);
     cStl.cfgViewAll(false);
-    for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB()+"_stl",nodePath()+tbl()+"_stl",fldCnt++,cStl,false,&full); ) {
+    for(int fldCnt = 0; SYS->db().at().dataSeek(fullDB()+"_stl",nodePath()+tbl()+"_stl",fldCnt++,cStl); ) {
 	if(mStProp.find(cStl.cfg("ID").getS()) == mStProp.end()) {
 	    if(!SYS->db().at().dataDel(fullDB()+"_stl",nodePath()+tbl()+"_stl",cStl,true,false,true))	break;
-	    if(full.empty()) fldCnt--;
+	    fldCnt--;
 	}
     }
 }
@@ -321,8 +317,7 @@ void Project::mimeDataList( vector<string> &list, const string &idb ) const
     cEl.cfgViewAll(false);
 
     list.clear();
-    vector<vector<string> > full;
-    for(int fldCnt = 0; SYS->db().at().dataSeek(wdb+"."+wtbl,mod->nodePath()+wtbl,fldCnt,cEl,false,&full); fldCnt++)
+    for(int fldCnt = 0; SYS->db().at().dataSeek(wdb+"."+wtbl,mod->nodePath()+wtbl,fldCnt,cEl,false,true); fldCnt++)
 	list.push_back(cEl.cfg("ID").getS());
 }
 
@@ -515,7 +510,6 @@ void Project::pageEnable( const string &pg, bool vl )
 
     //Call the connected sessions for add-remove a page
     MtxAlloc res(mHeritRes, true);
-
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(pL > 1) {
 	    AutoHD<SessPage> sP = mHerit[iH].at().nodeAt(pPath, 0, 0, 0, true);
@@ -987,7 +981,9 @@ void Page::postDisable( int flag )
 bool Page::cfgChange( TCfg &co, const TVariant &pc )
 {
     if(co.name() == "PR_TR") cfg("PROC").setNoTransl(!calcProgTr());
-    else if(co.name() == "PROC" && co.getS() != pc.getS()) procChange();
+
+    if(co.getS() == pc.getS()) return true;
+    if(co.name() == "PROC") procChange();
     modif();
     return true;
 }
@@ -1039,25 +1035,17 @@ string Page::calcLang( ) const
 {
     if(proc().empty() && !parent().freeStat()) return parent().at().calcLang();
 
-    string iprg = proc();
-    if(iprg.find("\n") == string::npos) {
-	iprg = iprg+"\n";
-	cfg("PROC").setS(iprg);
-    }
-    return iprg.substr(0,iprg.find("\n"));
+    return TSYS::strLine(proc(), 0);
 }
 
-bool Page::calcProgTr( )	{ return (!proc().size() && !parent().freeStat()) ? parent().at().calcProgTr() : cfg("PR_TR"); }
-
 string Page::calcProg( ) const
 {
     if(!proc().size() && !parent().freeStat()) return parent().at().calcProg();
 
     string iprg = proc();
-    size_t lng_end = iprg.find("\n");
-    if(lng_end == string::npos) lng_end = 0;
-    else lng_end++;
-    return iprg.substr(lng_end);
+    int off = 0;
+    TSYS::strLine(iprg, 0, &off);
+    return iprg.substr(off);
 }
 
 string Page::calcProgStors( const string &attr )
@@ -1073,12 +1061,6 @@ int Page::calcPer( ) const	{ return (mProcPer < 0 && !parent().freeStat()) ? par
 
 void Page::setCalcLang( const string &ilng )	{ cfg("PROC").setS(ilng.empty() ? "" : ilng+"\n"+calcProg()); }
 
-void Page::setCalcProgTr( bool vl )
-{
-    if(!proc().size() && !parent().freeStat())	parent().at().setCalcProgTr(vl);
-    else cfg("PR_TR") = vl;
-}
-
 void Page::setCalcProg( const string &iprg )	{ cfg("PROC").setS(calcLang()+"\n"+iprg); }
 
 void Page::setPrjFlags( int val )
@@ -1128,11 +1110,10 @@ void Page::load_( TConfig *icfg )
 
     //Creating for new pages
     map<string, bool>	itReg;
-    vector<vector<string> > full;
     TConfig cEl(&mod->elPage());
     //cEl.cfgViewAll(false);
     cEl.cfg("OWNER").setS(ownerFullId()+"/"+id(), true);
-    for(int fldCnt = 0; SYS->db().at().dataSeek(db+"."+tbl,mod->nodePath()+tbl,fldCnt++,cEl,false,&full); ) {
+    for(int fldCnt = 0; SYS->db().at().dataSeek(db+"."+tbl,mod->nodePath()+tbl,fldCnt++,cEl,false,true); ) {
 	string fId = cEl.cfg("ID").getS();
 	if(!pagePresent(fId))
 	    try { pageAdd(fId, "", ""); }
@@ -1172,12 +1153,11 @@ void Page::loadIO( )
     //Load cotainer widgets
     if(!isContainer()) return;
     map<string, bool>   itReg;
-    vector<vector<string> > full;
     TConfig cEl(&mod->elInclWdg());
     string db  = ownerProj()->DB();
     string tbl = ownerProj()->tbl()+"_incl";
     cEl.cfg("IDW").setS(path(), true);
-    for(int fldCnt = 0; SYS->db().at().dataSeek(db+"."+tbl,mod->nodePath()+tbl,fldCnt++,cEl,false,&full); ) {
+    for(int fldCnt = 0; SYS->db().at().dataSeek(db+"."+tbl,mod->nodePath()+tbl,fldCnt++,cEl); ) {
 	string sid  = cEl.cfg("ID").getS();
 	string spar = cEl.cfg("PARENT").getS();
 
@@ -1190,13 +1170,13 @@ void Page::loadIO( )
 	else if(mod->nodeAt(spar,0,0,0,true).freeStat() && sid.size() < spar.size() && spar.compare(spar.size()-sid.size(),sid.size(),sid) == 0) {
 	    if(wdgPresent(sid)) wdgDel(sid);
 	    SYS->db().at().dataDel(db+"."+tbl, mod->nodePath()+tbl, cEl, true);
-	    if(full.empty()) fldCnt--;
+	    fldCnt--;
 	    continue;
 	}
 	// Record without any changes
 	else if(!cEl.cfg("ATTRS").getS().size()) {
 	    SYS->db().at().dataDel(db+"."+tbl, mod->nodePath()+tbl, cEl, true);
-	    if(full.empty()) fldCnt--;
+	    fldCnt--;
 	}
 	if(!wdgPresent(sid))
 	    try{ wdgAdd(sid, "", ""); }
@@ -1329,9 +1309,11 @@ void Page::wdgAdd( const string &wid, const string &name, const string &ipath, b
     }
 
     //Call heritors include widgets update
-    for(unsigned i_h = 0; i_h < mHerit.size(); i_h++)
-	if(mHerit[i_h].at().enable())
-	    mHerit[i_h].at().inheritIncl(wid);
+    ResAlloc res(mHeritRes);
+    for(unsigned iH = 0; iH < mHerit.size(); iH++)
+	if(mHerit[iH].at().enable())
+	    mHerit[iH].at().inheritIncl(wid);
+    res.unlock();
 
     if(toRestoreInher)
 	throw TError(TError::Core_CntrWarning, nodePath().c_str(), _("Restoring '%s' from the base container!"), wid.c_str());
@@ -1413,6 +1395,7 @@ void Page::procChange( bool src )
     if(!src && proc().size()) return;
 
     //Update heritors' procedures
+    ResAlloc res(mHeritRes);
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(mHerit[iH].at().enable())
 	    mHerit[iH].at().procChange(false);
@@ -1767,9 +1750,9 @@ void PageWdg::setEnable( bool val, bool force )
 
     //Disable heritors widgets
     if(val)
-	for(unsigned i_h = 0; i_h < ownerPage().herit().size(); i_h++)
-	    if(ownerPage().herit()[i_h].at().wdgPresent(id()) && !ownerPage().herit()[i_h].at().wdgAt(id()).at().enable())
-		try { ownerPage().herit()[i_h].at().wdgAt(id()).at().setEnable(true); }
+	for(unsigned iH = 0; iH < ownerPage().herit().size(); iH++)
+	    if(ownerPage().herit()[iH].at().wdgPresent(id()) && !ownerPage().herit()[iH].at().wdgAt(id()).at().enable())
+		try { ownerPage().herit()[iH].at().wdgAt(id()).at().setEnable(true); }
 		catch(...) { mess_err(nodePath().c_str(),_("Error enabling the inheriting widget '%s'."),id().c_str()); }
 }
 
@@ -1888,6 +1871,7 @@ string PageWdg::resourceGet( const string &id, string *mime )
 void PageWdg::procChange( bool src )
 {
     //Update heritors' procedures
+    ResAlloc res(mHeritRes);
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(mHerit[iH].at().enable())
 	    mHerit[iH].at().procChange(false);
