@@ -361,6 +361,7 @@ AutoHD<Widget> Widget::parentNoLink( )	{ return parent().at().isLink() ? parent(
 void Widget::heritReg( Widget *wdg )
 {
     //Search for already registered widget-heritator
+    ResAlloc res(mHeritRes, true);
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(&mHerit[iH].at() == wdg)	return;
     mHerit.push_back(AutoHD<Widget>(wdg));
@@ -369,6 +370,7 @@ void Widget::heritReg( Widget *wdg )
 void Widget::heritUnreg( Widget *wdg )
 {
     //Search the widget-heritator
+    ResAlloc res(mHeritRes, true);
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(&mHerit[iH].at() == wdg) {
 	    mHerit.erase(mHerit.begin()+iH);
@@ -620,6 +622,7 @@ void Widget::attrAdd( TFld *attr, int pos, bool inher, bool forceMdf, bool allIn
     mtxAttr().unlock();
 
     //Update heritors' attributes
+    ResAlloc res(mHeritRes);
     for(unsigned iH = 0; allInher && iH < mHerit.size(); iH++)
 	if(mHerit[iH].at().enable())
 	    mHerit[iH].at().inheritAttr(anm);
@@ -630,10 +633,12 @@ void Widget::attrDel( const string &attr, bool allInher  )
     if(!attrPresent(attr)) return;
 
     //Delete from inheritant wigets
-    if(!(attrAt(attr).at().flgGlob()&Attr::Mutable) || allInher)
+    if(!(attrAt(attr).at().flgGlob()&Attr::Mutable) || allInher) {
+	ResAlloc res(mHeritRes);
 	for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	    if(mHerit[iH].at().enable())
 		mHerit[iH].at().attrDel(attr);
+    }
 
     //Self delete
     try {
@@ -711,6 +716,7 @@ bool Widget::attrChange( Attr &cfg, TVariant prev )
     if(cfg.owner() != this) return false;
 
     //Update heritors attributes
+    ResAlloc res(mHeritRes);
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(mHerit[iH].at().enable())
 	    mHerit[iH].at().inheritAttr(cfg.id());
@@ -735,6 +741,7 @@ void Widget::wdgAdd( const string &wid, const string &name, const string &path,
     wdgAt(wid).at().setName(name);
 
     //Call heritors include widgets update
+    ResAlloc res(mHeritRes);
     for(unsigned iH = 0; iH < mHerit.size(); iH++)
 	if(mHerit[iH].at().enable())
 	    mHerit[iH].at().inheritIncl(wid);
@@ -1459,9 +1466,12 @@ bool Widget::cntrCmdProcess( XMLNode *opt )
 	    if(ctrMkNode("area",opt,-1,"/proc/calc",_("Calculation"))) {
 		ctrMkNode("fld",opt,-1,"/proc/calc/progLng",_("Procedure language"),RWRWR_,"root",SUI_ID,4,"tp","str","dest","sel_ed","select","/plang/list",
 		    "help",_("Select the blank language to reset the widget procedure and language to the parent widget."));
-		ctrMkNode("fld",opt,-1,"/proc/calc/per",_("Period of the calculating, milliseconds"),RWRWR_,"root",SUI_ID,1,"tp","dec");
-		ctrMkNode("fld",opt,-1,"/proc/calc/prog_tr",_("Completely translate the procedure"),RWRWR_,"root",SUI_ID,1,"tp","bool");
-		ctrMkNode("fld",opt,-1,"/proc/calc/prog",_("Procedure"),RWRWR_,"root",SUI_ID,3,"tp","str","rows","10","SnthHgl","1");
+		if(calcLang().size())
+		    ctrMkNode("fld",opt,-1,"/proc/calc/per",_("Period of the calculating, milliseconds"),RWRWR_,"root",SUI_ID,1,"tp","dec");
+		if(calcProg().size() && !(!parent().freeStat() && calcProg() == parent().at().calcProg()))
+		    ctrMkNode("fld",opt,-1,"/proc/calc/prog_tr",_("Completely translate the procedure"),RWRWR_,"root",SUI_ID,1,"tp","bool");
+		if(calcLang().size())
+		    ctrMkNode("fld",opt,-1,"/proc/calc/prog",_("Procedure"),RWRWR_,"root",SUI_ID,3,"tp","str","rows","10","SnthHgl","1");
 	    }
 	}
 	return true;
