@@ -1,7 +1,7 @@
 
 //OpenSCADA file: tfunction.cpp
 /***************************************************************************
- *   Copyright (C) 2003-2019 by Roman Savochenko, <rom_as@oscada.org>      *
+ *   Copyright (C) 2003-2020 by Roman Savochenko, <roman@oscada.org>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -255,7 +255,7 @@ void TFunction::cntrCmdProc( XMLNode *opt )
 	ctrMkNode("oscada_cntr",opt,-1,"/",_("Function: ")+name(),R_R_R_,"root",grp);
 	if(ctrMkNode("area",opt,-1,"/func",_("Function"))) {
 	    if(ctrMkNode("area",opt,-1,"/func/st",_("State"))) {
-		ctrMkNode("fld",opt,-1,"/func/st/st",_("Accessing"),RWRWR_,"root",grp,1,"tp","bool");
+		ctrMkNode("fld",opt,-1,"/func/st/st",_("Accessible"),RWRWR_,"root",grp,1,"tp","bool");
 		ctrMkNode("fld",opt,-1,"/func/st/use",_("Used"),R_R_R_,"root",grp,1,"tp","dec");
 	    }
 	    if(ctrMkNode("area",opt,-1,"/func/cfg",_("Configuration"))) {
@@ -349,7 +349,10 @@ void TFunction::cntrCmdProc( XMLNode *opt )
 	if(ctrChkNode(opt,"get",RWRW__,"root",grp,SEC_RD))	opt->setText(mTVal?"1":"0");
 	if(ctrChkNode(opt,"set",RWRW__,"root",grp,SEC_WR)) {
 	    bool to_en_exec = s2i(opt->text());
-	    if(to_en_exec && !mTVal)	mTVal = new TValFunc(id()+"_exec",this);
+	    if(to_en_exec && !mTVal) {
+		if(!startStat()) setStart(true);
+		mTVal = new TValFunc(id()+"_exec",this);
+	    }
 	    if(!to_en_exec && mTVal)	{ delete mTVal; mTVal = NULL; }
 	}
     }
@@ -373,7 +376,7 @@ void TFunction::cntrCmdProc( XMLNode *opt )
     else if(a_path == "/exec/calc" && mTVal && ctrChkNode(opt,"set",RWRW__,"root",grp,SEC_WR)) {
 	int n_tcalc = s2i(TBDS::genDBGet(nodePath()+"ntCalc","1",opt->attr("user")));
 	string wuser = opt->attr("user");
-	time_t tm_lim = SYS->sysTm()+STD_WAIT_TM;
+	time_t tm_lim = SYS->sysTm()+STD_WAIT_TM+1;
 	int64_t t_cnt = TSYS::curTime();
 	for(int iC = 0; iC < n_tcalc && SYS->sysTm() < tm_lim; iC++)
 	    mTVal->calc(wuser);
