@@ -290,7 +290,6 @@ string TMess::translGet( const string &base, const string &lang, const string &s
 	    map<string, map<string,string> >::iterator im = trMessIdx.find(base);
 	    if(im != trMessIdx.end()) {
 		TConfig req;
-		vector<vector<string> > full;
 		for(map<string,string>::iterator is = im->second.begin(); rez.empty() && is != im->second.end(); ++is) {
 		    string trSrc = TSYS::strParse(is->first,0,"#"), trFld = TSYS::strParse(is->first,1,"#"), reqFld;
 		    bool isCfg = false;
@@ -307,8 +306,8 @@ string TMess::translGet( const string &base, const string &lang, const string &s
 			//  Get from config file or DB source
 			bool seekRez = false;
 			for(int inst = 0; rez.empty(); inst++) {
-			    seekRez = isCfg ? SYS->db().at().dataSeek("", trSrc.substr(4), inst, req, false, &full)
-					    : SYS->db().at().dataSeek(trSrc.substr(3), "", inst, req, false, &full);
+			    seekRez = isCfg ? SYS->db().at().dataSeek("", trSrc.substr(4), inst, req, false, true)
+					    : SYS->db().at().dataSeek(trSrc.substr(3), "", inst, req, false, true);
 			    if(!seekRez) break;
 			    rez = req.cfg(reqFld).getS();
 			}
@@ -409,16 +408,15 @@ void TMess::translReg( const string &mess, const string &src, const string &prms
 	}
 
 	TConfig req;
-	vector<vector<string> > full;
 	req.elem().fldAdd(new TFld("base","Base",TFld::String,TCfg::Key,"1000"));
 
 	MtxAlloc res(mRes, true);
 	for(unsigned i_l = 0; i_l < ls.size(); i_l++)
 	    if(ls[i_l] == DB_CFG)
-		for(int io_cnt = 0; SYS->db().at().dataSeek("","/" mess_TrUApiTbl,io_cnt++,req,false,&full); )
+		for(int io_cnt = 0; SYS->db().at().dataSeek("","/" mess_TrUApiTbl,io_cnt++,req,false,true); )
 		    trMessIdx[req.cfg("base").getS()]["cfg:/" mess_TrUApiTbl] = prms;
 	    else
-		for(int io_cnt = 0; SYS->db().at().dataSeek(ls[i_l]+"." mess_TrUApiTbl,"",io_cnt++,req,false,&full); )
+		for(int io_cnt = 0; SYS->db().at().dataSeek(ls[i_l]+"." mess_TrUApiTbl,"",io_cnt++,req,false,true); )
 		    trMessIdx[req.cfg("base").getS()]["db:"+ls[i_l]+"." mess_TrUApiTbl "#base"] = prms;
     }
     else {
